rem ************************************************************************
rem * install-headers.bat - generated by gendsp.pl
rem *
set msvc=%1
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\attribute.h %COINDIR%\include\Inventor\C\XML\attribute.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\document.h %COINDIR%\include\Inventor\C\XML\document.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\element.h %COINDIR%\include\Inventor\C\XML\element.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\entity.h %COINDIR%\include\Inventor\C\XML\entity.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\path.h %COINDIR%\include\Inventor\C\XML\path.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\types.h %COINDIR%\include\Inventor\C\XML\types.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\parser.h %COINDIR%\include\Inventor\C\XML\parser.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\XML\world.h %COINDIR%\include\Inventor\C\XML\world.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\hash.h %COINDIR%\include\Inventor\C\base\hash.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\heap.h %COINDIR%\include\Inventor\C\base\heap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\memalloc.h %COINDIR%\include\Inventor\C\base\memalloc.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\rbptree.h %COINDIR%\include\Inventor\C\base\rbptree.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\time.h %COINDIR%\include\Inventor\C\base\time.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\string.h %COINDIR%\include\Inventor\C\base\string.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\base\list.h %COINDIR%\include\Inventor\C\base\list.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\errors\error.h %COINDIR%\include\Inventor\C\errors\error.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\errors\debugerror.h %COINDIR%\include\Inventor\C\errors\debugerror.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\glue\gl.h %COINDIR%\include\Inventor\C\glue\gl.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\glue\dl.h %COINDIR%\include\Inventor\C\glue\dl.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\glue\spidermonkey.h %COINDIR%\include\Inventor\C\glue\spidermonkey.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\common.h %COINDIR%\include\Inventor\C\threads\common.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\thread.h %COINDIR%\include\Inventor\C\threads\thread.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\mutex.h %COINDIR%\include\Inventor\C\threads\mutex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\condvar.h %COINDIR%\include\Inventor\C\threads\condvar.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\recmutex.h %COINDIR%\include\Inventor\C\threads\recmutex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\rwmutex.h %COINDIR%\include\Inventor\C\threads\rwmutex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\storage.h %COINDIR%\include\Inventor\C\threads\storage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\worker.h %COINDIR%\include\Inventor\C\threads\worker.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\wpool.h %COINDIR%\include\Inventor\C\threads\wpool.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\sched.h %COINDIR%\include\Inventor\C\threads\sched.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\sync.h %COINDIR%\include\Inventor\C\threads\sync.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\fifo.h %COINDIR%\include\Inventor\C\threads\fifo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\threads\barrier.h %COINDIR%\include\Inventor\C\threads\barrier.h >nul:
copy /Y ..\%msvc%\include\Inventor\C\basic.h %COINDIR%\include\Inventor\C\basic.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\C\tidbits.h %COINDIR%\include\Inventor\C\tidbits.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRML.h %COINDIR%\include\Inventor\VRMLnodes\SoVRML.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLAnchor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLAnchor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLAppearance.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLAppearance.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLAudioClip.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLAudioClip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLBackground.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLBackground.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLBillboard.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLBillboard.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLBox.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLBox.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLCollision.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLCollision.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLColor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLColor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLColorInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLColorInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLCone.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLCone.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLCoordinate.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLCoordinate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLCoordinateInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLCoordinateInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLCylinder.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLCylinder.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLCylinderSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLCylinderSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLDirectionalLight.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLDirectionalLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLDragSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLDragSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLElevationGrid.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLElevationGrid.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLExtrusion.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLExtrusion.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLFog.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLFog.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLFontStyle.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLFontStyle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLGeometry.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLGeometry.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLGroup.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLGroup.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLImageTexture.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLImageTexture.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLIndexedFaceSet.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLIndexedFaceSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLIndexedLine.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLIndexedLine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLIndexedLineSet.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLIndexedLineSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLIndexedShape.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLIndexedShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLInline.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLInline.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLLOD.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLLOD.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLLight.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLMacros.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLMacros.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLMaterial.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLMaterial.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLMovieTexture.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLMovieTexture.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLNavigationInfo.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLNavigationInfo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLNodes.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLNodes.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLNormal.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLNormal.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLNormalInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLNormalInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLOrientationInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLOrientationInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLParent.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLParent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLPixelTexture.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLPixelTexture.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLPlaneSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLPlaneSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLPointLight.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLPointLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLPointSet.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLPointSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLPositionInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLPositionInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLProximitySensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLProximitySensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLScalarInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLScalarInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLScript.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLScript.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLShape.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSound.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSound.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSphere.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSphere.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSphereSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSphereSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSpotLight.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSpotLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSubInterpolator.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSubInterpolator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLSwitch.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLSwitch.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLText.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLText.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLTexture.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLTexture.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLTextureCoordinate.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLTextureCoordinate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLTextureTransform.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLTextureTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLTimeSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLTimeSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLTouchSensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLTouchSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLTransform.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLVertexLine.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLVertexLine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLVertexPoint.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLVertexPoint.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLVertexShape.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLVertexShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLViewpoint.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLViewpoint.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLVisibilitySensor.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLVisibilitySensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\VRMLnodes\SoVRMLWorldInfo.h %COINDIR%\include\Inventor\VRMLnodes\SoVRMLWorldInfo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoSubAction.h %COINDIR%\include\Inventor\actions\SoSubAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoActions.h %COINDIR%\include\Inventor\actions\SoActions.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoAction.h %COINDIR%\include\Inventor\actions\SoAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoBoxHighlightRenderAction.h %COINDIR%\include\Inventor\actions\SoBoxHighlightRenderAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoCallbackAction.h %COINDIR%\include\Inventor\actions\SoCallbackAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoGLRenderAction.h %COINDIR%\include\Inventor\actions\SoGLRenderAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoGetBoundingBoxAction.h %COINDIR%\include\Inventor\actions\SoGetBoundingBoxAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoGetMatrixAction.h %COINDIR%\include\Inventor\actions\SoGetMatrixAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoGetPrimitiveCountAction.h %COINDIR%\include\Inventor\actions\SoGetPrimitiveCountAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoHandleEventAction.h %COINDIR%\include\Inventor\actions\SoHandleEventAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoLineHighlightRenderAction.h %COINDIR%\include\Inventor\actions\SoLineHighlightRenderAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoPickAction.h %COINDIR%\include\Inventor\actions\SoPickAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoRayPickAction.h %COINDIR%\include\Inventor\actions\SoRayPickAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoReorganizeAction.h %COINDIR%\include\Inventor\actions\SoReorganizeAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoSearchAction.h %COINDIR%\include\Inventor\actions\SoSearchAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoSimplifyAction.h %COINDIR%\include\Inventor\actions\SoSimplifyAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoToVRMLAction.h %COINDIR%\include\Inventor\actions\SoToVRMLAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoToVRML2Action.h %COINDIR%\include\Inventor\actions\SoToVRML2Action.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoWriteAction.h %COINDIR%\include\Inventor\actions\SoWriteAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\actions\SoAudioRenderAction.h %COINDIR%\include\Inventor\actions\SoAudioRenderAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\HardCopy\SoHardCopy.h %COINDIR%\include\Inventor\annex\HardCopy\SoHardCopy.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\HardCopy\SoPSVectorOutput.h %COINDIR%\include\Inventor\annex\HardCopy\SoPSVectorOutput.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\HardCopy\SoVectorOutput.h %COINDIR%\include\Inventor\annex\HardCopy\SoVectorOutput.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\HardCopy\SoVectorizeAction.h %COINDIR%\include\Inventor\annex\HardCopy\SoVectorizeAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\HardCopy\SoVectorizePSAction.h %COINDIR%\include\Inventor\annex\HardCopy\SoVectorizePSAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\ForeignFiles\SoForeignFileKit.h %COINDIR%\include\Inventor\annex\ForeignFiles\SoForeignFileKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\ForeignFiles\SoSTLFileKit.h %COINDIR%\include\Inventor\annex\ForeignFiles\SoSTLFileKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\nodes\SoShadowGroup.h %COINDIR%\include\Inventor\annex\FXViz\nodes\SoShadowGroup.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\nodes\SoShadowStyle.h %COINDIR%\include\Inventor\annex\FXViz\nodes\SoShadowStyle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\nodes\SoShadowDirectionalLight.h %COINDIR%\include\Inventor\annex\FXViz\nodes\SoShadowDirectionalLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\nodes\SoShadowSpotLight.h %COINDIR%\include\Inventor\annex\FXViz\nodes\SoShadowSpotLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\nodes\SoShadowCulling.h %COINDIR%\include\Inventor\annex\FXViz\nodes\SoShadowCulling.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\elements\SoShadowStyleElement.h %COINDIR%\include\Inventor\annex\FXViz\elements\SoShadowStyleElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\FXViz\elements\SoGLShadowCullingElement.h %COINDIR%\include\Inventor\annex\FXViz\elements\SoGLShadowCullingElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\nodes\SoProfilerStats.h %COINDIR%\include\Inventor\annex\Profiler\nodes\SoProfilerStats.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\elements\SoProfilerElement.h %COINDIR%\include\Inventor\annex\Profiler\elements\SoProfilerElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\nodekits\SoNodeVisualize.h %COINDIR%\include\Inventor\annex\Profiler\nodekits\SoNodeVisualize.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\nodekits\SoProfilerOverlayKit.h %COINDIR%\include\Inventor\annex\Profiler\nodekits\SoProfilerOverlayKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\nodekits\SoProfilerTopKit.h %COINDIR%\include\Inventor\annex\Profiler\nodekits\SoProfilerTopKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\nodekits\SoScrollingGraphKit.h %COINDIR%\include\Inventor\annex\Profiler\nodekits\SoScrollingGraphKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\nodekits\SoProfilerVisualizeKit.h %COINDIR%\include\Inventor\annex\Profiler\nodekits\SoProfilerVisualizeKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\engines\SoProfilerTopEngine.h %COINDIR%\include\Inventor\annex\Profiler\engines\SoProfilerTopEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\utils\SoProfilingReportGenerator.h %COINDIR%\include\Inventor\annex\Profiler\utils\SoProfilingReportGenerator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\SbProfilingData.h %COINDIR%\include\Inventor\annex\Profiler\SbProfilingData.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\annex\Profiler\SoProfiler.h %COINDIR%\include\Inventor\annex\Profiler\SoProfiler.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\bundles\SoBundle.h %COINDIR%\include\Inventor\bundles\SoBundle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\bundles\SoMaterialBundle.h %COINDIR%\include\Inventor\bundles\SoMaterialBundle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\bundles\SoNormalBundle.h %COINDIR%\include\Inventor\bundles\SoNormalBundle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\bundles\SoVertexAttributeBundle.h %COINDIR%\include\Inventor\bundles\SoVertexAttributeBundle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\bundles\SoTextureCoordinateBundle.h %COINDIR%\include\Inventor\bundles\SoTextureCoordinateBundle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoBoundingBoxCache.h %COINDIR%\include\Inventor\caches\SoBoundingBoxCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoCache.h %COINDIR%\include\Inventor\caches\SoCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoConvexDataCache.h %COINDIR%\include\Inventor\caches\SoConvexDataCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoGLCacheList.h %COINDIR%\include\Inventor\caches\SoGLCacheList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoGLRenderCache.h %COINDIR%\include\Inventor\caches\SoGLRenderCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoNormalCache.h %COINDIR%\include\Inventor\caches\SoNormalCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoPrimitiveVertexCache.h %COINDIR%\include\Inventor\caches\SoPrimitiveVertexCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\caches\SoTextureCoordinateCache.h %COINDIR%\include\Inventor\caches\SoTextureCoordinateCache.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\collision\SoIntersectionDetectionAction.h %COINDIR%\include\Inventor\collision\SoIntersectionDetectionAction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoSubDetail.h %COINDIR%\include\Inventor\details\SoSubDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoDetail.h %COINDIR%\include\Inventor\details\SoDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoDetails.h %COINDIR%\include\Inventor\details\SoDetails.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoConeDetail.h %COINDIR%\include\Inventor\details\SoConeDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoCubeDetail.h %COINDIR%\include\Inventor\details\SoCubeDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoCylinderDetail.h %COINDIR%\include\Inventor\details\SoCylinderDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoFaceDetail.h %COINDIR%\include\Inventor\details\SoFaceDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoLineDetail.h %COINDIR%\include\Inventor\details\SoLineDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoNodeKitDetail.h %COINDIR%\include\Inventor\details\SoNodeKitDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoPointDetail.h %COINDIR%\include\Inventor\details\SoPointDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\details\SoTextDetail.h %COINDIR%\include\Inventor\details\SoTextDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoDragger.h %COINDIR%\include\Inventor\draggers\SoDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoCenterballDragger.h %COINDIR%\include\Inventor\draggers\SoCenterballDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoDirectionalLightDragger.h %COINDIR%\include\Inventor\draggers\SoDirectionalLightDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoDragPointDragger.h %COINDIR%\include\Inventor\draggers\SoDragPointDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoHandleBoxDragger.h %COINDIR%\include\Inventor\draggers\SoHandleBoxDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoJackDragger.h %COINDIR%\include\Inventor\draggers\SoJackDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoPointLightDragger.h %COINDIR%\include\Inventor\draggers\SoPointLightDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoRotateCylindricalDragger.h %COINDIR%\include\Inventor\draggers\SoRotateCylindricalDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoRotateDiscDragger.h %COINDIR%\include\Inventor\draggers\SoRotateDiscDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoRotateSphericalDragger.h %COINDIR%\include\Inventor\draggers\SoRotateSphericalDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoScale1Dragger.h %COINDIR%\include\Inventor\draggers\SoScale1Dragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoScale2Dragger.h %COINDIR%\include\Inventor\draggers\SoScale2Dragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoScale2UniformDragger.h %COINDIR%\include\Inventor\draggers\SoScale2UniformDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoScaleUniformDragger.h %COINDIR%\include\Inventor\draggers\SoScaleUniformDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoSpotLightDragger.h %COINDIR%\include\Inventor\draggers\SoSpotLightDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTabBoxDragger.h %COINDIR%\include\Inventor\draggers\SoTabBoxDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTabPlaneDragger.h %COINDIR%\include\Inventor\draggers\SoTabPlaneDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTrackballDragger.h %COINDIR%\include\Inventor\draggers\SoTrackballDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTransformBoxDragger.h %COINDIR%\include\Inventor\draggers\SoTransformBoxDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTransformerDragger.h %COINDIR%\include\Inventor\draggers\SoTransformerDragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTranslate1Dragger.h %COINDIR%\include\Inventor\draggers\SoTranslate1Dragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\draggers\SoTranslate2Dragger.h %COINDIR%\include\Inventor\draggers\SoTranslate2Dragger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoSubElement.h %COINDIR%\include\Inventor\elements\SoSubElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoElements.h %COINDIR%\include\Inventor\elements\SoElements.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoAccumulatedElement.h %COINDIR%\include\Inventor\elements\SoAccumulatedElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoAmbientColorElement.h %COINDIR%\include\Inventor\elements\SoAmbientColorElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoAnnoText3CharOrientElement.h %COINDIR%\include\Inventor\elements\SoAnnoText3CharOrientElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoAnnoText3FontSizeHintElement.h %COINDIR%\include\Inventor\elements\SoAnnoText3FontSizeHintElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoAnnoText3RenderPrintElement.h %COINDIR%\include\Inventor\elements\SoAnnoText3RenderPrintElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoBBoxModelMatrixElement.h %COINDIR%\include\Inventor\elements\SoBBoxModelMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoBumpMapElement.h %COINDIR%\include\Inventor\elements\SoBumpMapElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoBumpMapCoordinateElement.h %COINDIR%\include\Inventor\elements\SoBumpMapCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoBumpMapMatrixElement.h %COINDIR%\include\Inventor\elements\SoBumpMapMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoCacheElement.h %COINDIR%\include\Inventor\elements\SoCacheElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoCacheHintElement.h %COINDIR%\include\Inventor\elements\SoCacheHintElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoClipPlaneElement.h %COINDIR%\include\Inventor\elements\SoClipPlaneElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoComplexityElement.h %COINDIR%\include\Inventor\elements\SoComplexityElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoComplexityTypeElement.h %COINDIR%\include\Inventor\elements\SoComplexityTypeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoCoordinateElement.h %COINDIR%\include\Inventor\elements\SoCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoCreaseAngleElement.h %COINDIR%\include\Inventor\elements\SoCreaseAngleElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoCullElement.h %COINDIR%\include\Inventor\elements\SoCullElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoDecimationPercentageElement.h %COINDIR%\include\Inventor\elements\SoDecimationPercentageElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoDecimationTypeElement.h %COINDIR%\include\Inventor\elements\SoDecimationTypeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoDiffuseColorElement.h %COINDIR%\include\Inventor\elements\SoDiffuseColorElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoDrawStyleElement.h %COINDIR%\include\Inventor\elements\SoDrawStyleElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoElement.h %COINDIR%\include\Inventor\elements\SoElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoEmissiveColorElement.h %COINDIR%\include\Inventor\elements\SoEmissiveColorElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoEnvironmentElement.h %COINDIR%\include\Inventor\elements\SoEnvironmentElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoFloatElement.h %COINDIR%\include\Inventor\elements\SoFloatElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoFocalDistanceElement.h %COINDIR%\include\Inventor\elements\SoFocalDistanceElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoFontNameElement.h %COINDIR%\include\Inventor\elements\SoFontNameElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoFontSizeElement.h %COINDIR%\include\Inventor\elements\SoFontSizeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGeoElement.h %COINDIR%\include\Inventor\elements\SoGeoElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLCacheContextElement.h %COINDIR%\include\Inventor\elements\SoGLCacheContextElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLClipPlaneElement.h %COINDIR%\include\Inventor\elements\SoGLClipPlaneElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLColorIndexElement.h %COINDIR%\include\Inventor\elements\SoGLColorIndexElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLCoordinateElement.h %COINDIR%\include\Inventor\elements\SoGLCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLDisplayList.h %COINDIR%\include\Inventor\elements\SoGLDisplayList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLDrawStyleElement.h %COINDIR%\include\Inventor\elements\SoGLDrawStyleElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLEnvironmentElement.h %COINDIR%\include\Inventor\elements\SoGLEnvironmentElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLLazyElement.h %COINDIR%\include\Inventor\elements\SoGLLazyElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLLightIdElement.h %COINDIR%\include\Inventor\elements\SoGLLightIdElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLLinePatternElement.h %COINDIR%\include\Inventor\elements\SoGLLinePatternElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLLineWidthElement.h %COINDIR%\include\Inventor\elements\SoGLLineWidthElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLModelMatrixElement.h %COINDIR%\include\Inventor\elements\SoGLModelMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLMultiTextureCoordinateElement.h %COINDIR%\include\Inventor\elements\SoGLMultiTextureCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLMultiTextureEnabledElement.h %COINDIR%\include\Inventor\elements\SoGLMultiTextureEnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLMultiTextureMatrixElement.h %COINDIR%\include\Inventor\elements\SoGLMultiTextureMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLMultiTextureImageElement.h %COINDIR%\include\Inventor\elements\SoGLMultiTextureImageElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLNormalElement.h %COINDIR%\include\Inventor\elements\SoGLNormalElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLNormalizeElement.h %COINDIR%\include\Inventor\elements\SoGLNormalizeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLPointSizeElement.h %COINDIR%\include\Inventor\elements\SoGLPointSizeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLPolygonOffsetElement.h %COINDIR%\include\Inventor\elements\SoGLPolygonOffsetElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLProjectionMatrixElement.h %COINDIR%\include\Inventor\elements\SoGLProjectionMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLRenderPassElement.h %COINDIR%\include\Inventor\elements\SoGLRenderPassElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLShapeHintsElement.h %COINDIR%\include\Inventor\elements\SoGLShapeHintsElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLShadeModelElement.h %COINDIR%\include\Inventor\elements\SoGLShadeModelElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLTextureCoordinateElement.h %COINDIR%\include\Inventor\elements\SoGLTextureCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLTextureEnabledElement.h %COINDIR%\include\Inventor\elements\SoGLTextureEnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLTexture3EnabledElement.h %COINDIR%\include\Inventor\elements\SoGLTexture3EnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLTextureImageElement.h %COINDIR%\include\Inventor\elements\SoGLTextureImageElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLTextureMatrixElement.h %COINDIR%\include\Inventor\elements\SoGLTextureMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLUpdateAreaElement.h %COINDIR%\include\Inventor\elements\SoGLUpdateAreaElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLVBOElement.h %COINDIR%\include\Inventor\elements\SoGLVBOElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLViewingMatrixElement.h %COINDIR%\include\Inventor\elements\SoGLViewingMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLViewportRegionElement.h %COINDIR%\include\Inventor\elements\SoGLViewportRegionElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoInt32Element.h %COINDIR%\include\Inventor\elements\SoInt32Element.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLazyElement.h %COINDIR%\include\Inventor\elements\SoLazyElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLightAttenuationElement.h %COINDIR%\include\Inventor\elements\SoLightAttenuationElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLightElement.h %COINDIR%\include\Inventor\elements\SoLightElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLightModelElement.h %COINDIR%\include\Inventor\elements\SoLightModelElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLinePatternElement.h %COINDIR%\include\Inventor\elements\SoLinePatternElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLineWidthElement.h %COINDIR%\include\Inventor\elements\SoLineWidthElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLocalBBoxMatrixElement.h %COINDIR%\include\Inventor\elements\SoLocalBBoxMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoLongElement.h %COINDIR%\include\Inventor\elements\SoLongElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoMaterialBindingElement.h %COINDIR%\include\Inventor\elements\SoMaterialBindingElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoVertexAttributeBindingElement.h %COINDIR%\include\Inventor\elements\SoVertexAttributeBindingElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoModelMatrixElement.h %COINDIR%\include\Inventor\elements\SoModelMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoMultiTextureCoordinateElement.h %COINDIR%\include\Inventor\elements\SoMultiTextureCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoMultiTextureEnabledElement.h %COINDIR%\include\Inventor\elements\SoMultiTextureEnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoMultiTextureMatrixElement.h %COINDIR%\include\Inventor\elements\SoMultiTextureMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoMultiTextureImageElement.h %COINDIR%\include\Inventor\elements\SoMultiTextureImageElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoNormalBindingElement.h %COINDIR%\include\Inventor\elements\SoNormalBindingElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoNormalElement.h %COINDIR%\include\Inventor\elements\SoNormalElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoOverrideElement.h %COINDIR%\include\Inventor\elements\SoOverrideElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoPickRayElement.h %COINDIR%\include\Inventor\elements\SoPickRayElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoPickStyleElement.h %COINDIR%\include\Inventor\elements\SoPickStyleElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoPointSizeElement.h %COINDIR%\include\Inventor\elements\SoPointSizeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoPolygonOffsetElement.h %COINDIR%\include\Inventor\elements\SoPolygonOffsetElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoProfileCoordinateElement.h %COINDIR%\include\Inventor\elements\SoProfileCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoProfileElement.h %COINDIR%\include\Inventor\elements\SoProfileElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoProjectionMatrixElement.h %COINDIR%\include\Inventor\elements\SoProjectionMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoReplacedElement.h %COINDIR%\include\Inventor\elements\SoReplacedElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoShapeHintsElement.h %COINDIR%\include\Inventor\elements\SoShapeHintsElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoShapeStyleElement.h %COINDIR%\include\Inventor\elements\SoShapeStyleElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoShininessElement.h %COINDIR%\include\Inventor\elements\SoShininessElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoSpecularColorElement.h %COINDIR%\include\Inventor\elements\SoSpecularColorElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoSwitchElement.h %COINDIR%\include\Inventor\elements\SoSwitchElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextOutlineEnabledElement.h %COINDIR%\include\Inventor\elements\SoTextOutlineEnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureCombineElement.h %COINDIR%\include\Inventor\elements\SoTextureCombineElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureCoordinateBindingElement.h %COINDIR%\include\Inventor\elements\SoTextureCoordinateBindingElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureCoordinateElement.h %COINDIR%\include\Inventor\elements\SoTextureCoordinateElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureEnabledElement.h %COINDIR%\include\Inventor\elements\SoTextureEnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTexture3EnabledElement.h %COINDIR%\include\Inventor\elements\SoTexture3EnabledElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureImageElement.h %COINDIR%\include\Inventor\elements\SoTextureImageElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureMatrixElement.h %COINDIR%\include\Inventor\elements\SoTextureMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureOverrideElement.h %COINDIR%\include\Inventor\elements\SoTextureOverrideElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureQualityElement.h %COINDIR%\include\Inventor\elements\SoTextureQualityElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTextureUnitElement.h %COINDIR%\include\Inventor\elements\SoTextureUnitElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoTransparencyElement.h %COINDIR%\include\Inventor\elements\SoTransparencyElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoUnitsElement.h %COINDIR%\include\Inventor\elements\SoUnitsElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoViewVolumeElement.h %COINDIR%\include\Inventor\elements\SoViewVolumeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoViewingMatrixElement.h %COINDIR%\include\Inventor\elements\SoViewingMatrixElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoViewportRegionElement.h %COINDIR%\include\Inventor\elements\SoViewportRegionElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoWindowElement.h %COINDIR%\include\Inventor\elements\SoWindowElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoListenerPositionElement.h %COINDIR%\include\Inventor\elements\SoListenerPositionElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoListenerOrientationElement.h %COINDIR%\include\Inventor\elements\SoListenerOrientationElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoListenerGainElement.h %COINDIR%\include\Inventor\elements\SoListenerGainElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoListenerDopplerElement.h %COINDIR%\include\Inventor\elements\SoListenerDopplerElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoSoundElement.h %COINDIR%\include\Inventor\elements\SoSoundElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLShaderProgramElement.h %COINDIR%\include\Inventor\elements\SoGLShaderProgramElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoDepthBufferElement.h %COINDIR%\include\Inventor\elements\SoDepthBufferElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLDepthBufferElement.h %COINDIR%\include\Inventor\elements\SoGLDepthBufferElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoVertexAttributeElement.h %COINDIR%\include\Inventor\elements\SoVertexAttributeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\elements\SoGLVertexAttributeElement.h %COINDIR%\include\Inventor\elements\SoGLVertexAttributeElement.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoSubEngine.h %COINDIR%\include\Inventor\engines\SoSubEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoSubNodeEngine.h %COINDIR%\include\Inventor\engines\SoSubNodeEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoEngines.h %COINDIR%\include\Inventor\engines\SoEngines.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoBoolOperation.h %COINDIR%\include\Inventor\engines\SoBoolOperation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoCalculator.h %COINDIR%\include\Inventor\engines\SoCalculator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoCompose.h %COINDIR%\include\Inventor\engines\SoCompose.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComposeMatrix.h %COINDIR%\include\Inventor\engines\SoComposeMatrix.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComposeRotation.h %COINDIR%\include\Inventor\engines\SoComposeRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComposeRotationFromTo.h %COINDIR%\include\Inventor\engines\SoComposeRotationFromTo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComposeVec2f.h %COINDIR%\include\Inventor\engines\SoComposeVec2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComposeVec3f.h %COINDIR%\include\Inventor\engines\SoComposeVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComposeVec4f.h %COINDIR%\include\Inventor\engines\SoComposeVec4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoComputeBoundingBox.h %COINDIR%\include\Inventor\engines\SoComputeBoundingBox.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoConcatenate.h %COINDIR%\include\Inventor\engines\SoConcatenate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoCounter.h %COINDIR%\include\Inventor\engines\SoCounter.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoDecomposeMatrix.h %COINDIR%\include\Inventor\engines\SoDecomposeMatrix.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoDecomposeRotation.h %COINDIR%\include\Inventor\engines\SoDecomposeRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoDecomposeVec2f.h %COINDIR%\include\Inventor\engines\SoDecomposeVec2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoDecomposeVec3f.h %COINDIR%\include\Inventor\engines\SoDecomposeVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoDecomposeVec4f.h %COINDIR%\include\Inventor\engines\SoDecomposeVec4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoElapsedTime.h %COINDIR%\include\Inventor\engines\SoElapsedTime.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoEngine.h %COINDIR%\include\Inventor\engines\SoEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoEngineOutput.h %COINDIR%\include\Inventor\engines\SoEngineOutput.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoFieldConverter.h %COINDIR%\include\Inventor\engines\SoFieldConverter.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoGate.h %COINDIR%\include\Inventor\engines\SoGate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoInterpolate.h %COINDIR%\include\Inventor\engines\SoInterpolate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoInterpolateFloat.h %COINDIR%\include\Inventor\engines\SoInterpolateFloat.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoInterpolateRotation.h %COINDIR%\include\Inventor\engines\SoInterpolateRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoInterpolateVec2f.h %COINDIR%\include\Inventor\engines\SoInterpolateVec2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoInterpolateVec3f.h %COINDIR%\include\Inventor\engines\SoInterpolateVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoInterpolateVec4f.h %COINDIR%\include\Inventor\engines\SoInterpolateVec4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoNodeEngine.h %COINDIR%\include\Inventor\engines\SoNodeEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoOnOff.h %COINDIR%\include\Inventor\engines\SoOnOff.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoOneShot.h %COINDIR%\include\Inventor\engines\SoOneShot.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoOutputData.h %COINDIR%\include\Inventor\engines\SoOutputData.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoSelectOne.h %COINDIR%\include\Inventor\engines\SoSelectOne.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoTimeCounter.h %COINDIR%\include\Inventor\engines\SoTimeCounter.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoTransformVec3f.h %COINDIR%\include\Inventor\engines\SoTransformVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoTriggerAny.h %COINDIR%\include\Inventor\engines\SoTriggerAny.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoTexture2Convert.h %COINDIR%\include\Inventor\engines\SoTexture2Convert.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\engines\SoHeightMapToNormalMap.h %COINDIR%\include\Inventor\engines\SoHeightMapToNormalMap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\errors\SoErrors.h %COINDIR%\include\Inventor\errors\SoErrors.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\errors\SoDebugError.h %COINDIR%\include\Inventor\errors\SoDebugError.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\errors\SoError.h %COINDIR%\include\Inventor\errors\SoError.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\errors\SoMemoryError.h %COINDIR%\include\Inventor\errors\SoMemoryError.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\errors\SoReadError.h %COINDIR%\include\Inventor\errors\SoReadError.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoSubEvent.h %COINDIR%\include\Inventor\events\SoSubEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoButtonEvent.h %COINDIR%\include\Inventor\events\SoButtonEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoEvent.h %COINDIR%\include\Inventor\events\SoEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoEvents.h %COINDIR%\include\Inventor\events\SoEvents.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoKeyboardEvent.h %COINDIR%\include\Inventor\events\SoKeyboardEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoLocation2Event.h %COINDIR%\include\Inventor\events\SoLocation2Event.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoMotion3Event.h %COINDIR%\include\Inventor\events\SoMotion3Event.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoMouseButtonEvent.h %COINDIR%\include\Inventor\events\SoMouseButtonEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\events\SoSpaceballButtonEvent.h %COINDIR%\include\Inventor\events\SoSpaceballButtonEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSubField.h %COINDIR%\include\Inventor\fields\SoSubField.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoFields.h %COINDIR%\include\Inventor\fields\SoFields.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoField.h %COINDIR%\include\Inventor\fields\SoField.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoFieldContainer.h %COINDIR%\include\Inventor\fields\SoFieldContainer.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoFieldData.h %COINDIR%\include\Inventor\fields\SoFieldData.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFBitMask.h %COINDIR%\include\Inventor\fields\SoMFBitMask.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFBool.h %COINDIR%\include\Inventor\fields\SoMFBool.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFColor.h %COINDIR%\include\Inventor\fields\SoMFColor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFColorRGBA.h %COINDIR%\include\Inventor\fields\SoMFColorRGBA.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFDouble.h %COINDIR%\include\Inventor\fields\SoMFDouble.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFEngine.h %COINDIR%\include\Inventor\fields\SoMFEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFEnum.h %COINDIR%\include\Inventor\fields\SoMFEnum.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFFloat.h %COINDIR%\include\Inventor\fields\SoMFFloat.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFInt32.h %COINDIR%\include\Inventor\fields\SoMFInt32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFLong.h %COINDIR%\include\Inventor\fields\SoMFLong.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFMatrix.h %COINDIR%\include\Inventor\fields\SoMFMatrix.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFName.h %COINDIR%\include\Inventor\fields\SoMFName.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFNode.h %COINDIR%\include\Inventor\fields\SoMFNode.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFPath.h %COINDIR%\include\Inventor\fields\SoMFPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFPlane.h %COINDIR%\include\Inventor\fields\SoMFPlane.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFRotation.h %COINDIR%\include\Inventor\fields\SoMFRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFShort.h %COINDIR%\include\Inventor\fields\SoMFShort.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFString.h %COINDIR%\include\Inventor\fields\SoMFString.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFTime.h %COINDIR%\include\Inventor\fields\SoMFTime.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFUInt32.h %COINDIR%\include\Inventor\fields\SoMFUInt32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFULong.h %COINDIR%\include\Inventor\fields\SoMFULong.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFUShort.h %COINDIR%\include\Inventor\fields\SoMFUShort.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec2b.h %COINDIR%\include\Inventor\fields\SoMFVec2b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec2s.h %COINDIR%\include\Inventor\fields\SoMFVec2s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec2i32.h %COINDIR%\include\Inventor\fields\SoMFVec2i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec2f.h %COINDIR%\include\Inventor\fields\SoMFVec2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec2d.h %COINDIR%\include\Inventor\fields\SoMFVec2d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec3b.h %COINDIR%\include\Inventor\fields\SoMFVec3b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec3s.h %COINDIR%\include\Inventor\fields\SoMFVec3s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec3i32.h %COINDIR%\include\Inventor\fields\SoMFVec3i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec3f.h %COINDIR%\include\Inventor\fields\SoMFVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec3d.h %COINDIR%\include\Inventor\fields\SoMFVec3d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4b.h %COINDIR%\include\Inventor\fields\SoMFVec4b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4ub.h %COINDIR%\include\Inventor\fields\SoMFVec4ub.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4s.h %COINDIR%\include\Inventor\fields\SoMFVec4s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4us.h %COINDIR%\include\Inventor\fields\SoMFVec4us.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4i32.h %COINDIR%\include\Inventor\fields\SoMFVec4i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4ui32.h %COINDIR%\include\Inventor\fields\SoMFVec4ui32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4f.h %COINDIR%\include\Inventor\fields\SoMFVec4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMFVec4d.h %COINDIR%\include\Inventor\fields\SoMFVec4d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoMField.h %COINDIR%\include\Inventor\fields\SoMField.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBitMask.h %COINDIR%\include\Inventor\fields\SoSFBitMask.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBool.h %COINDIR%\include\Inventor\fields\SoSFBool.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox2s.h %COINDIR%\include\Inventor\fields\SoSFBox2s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox2i32.h %COINDIR%\include\Inventor\fields\SoSFBox2i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox2f.h %COINDIR%\include\Inventor\fields\SoSFBox2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox2d.h %COINDIR%\include\Inventor\fields\SoSFBox2d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox3s.h %COINDIR%\include\Inventor\fields\SoSFBox3s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox3i32.h %COINDIR%\include\Inventor\fields\SoSFBox3i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox3f.h %COINDIR%\include\Inventor\fields\SoSFBox3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFBox3d.h %COINDIR%\include\Inventor\fields\SoSFBox3d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFColor.h %COINDIR%\include\Inventor\fields\SoSFColor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFColorRGBA.h %COINDIR%\include\Inventor\fields\SoSFColorRGBA.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFDouble.h %COINDIR%\include\Inventor\fields\SoSFDouble.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFEngine.h %COINDIR%\include\Inventor\fields\SoSFEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFEnum.h %COINDIR%\include\Inventor\fields\SoSFEnum.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFFloat.h %COINDIR%\include\Inventor\fields\SoSFFloat.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFImage.h %COINDIR%\include\Inventor\fields\SoSFImage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFImage3.h %COINDIR%\include\Inventor\fields\SoSFImage3.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFInt32.h %COINDIR%\include\Inventor\fields\SoSFInt32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFLong.h %COINDIR%\include\Inventor\fields\SoSFLong.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFMatrix.h %COINDIR%\include\Inventor\fields\SoSFMatrix.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFName.h %COINDIR%\include\Inventor\fields\SoSFName.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFNode.h %COINDIR%\include\Inventor\fields\SoSFNode.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFPath.h %COINDIR%\include\Inventor\fields\SoSFPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFPlane.h %COINDIR%\include\Inventor\fields\SoSFPlane.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFRotation.h %COINDIR%\include\Inventor\fields\SoSFRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFShort.h %COINDIR%\include\Inventor\fields\SoSFShort.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFString.h %COINDIR%\include\Inventor\fields\SoSFString.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFTime.h %COINDIR%\include\Inventor\fields\SoSFTime.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFTrigger.h %COINDIR%\include\Inventor\fields\SoSFTrigger.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFUInt32.h %COINDIR%\include\Inventor\fields\SoSFUInt32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFULong.h %COINDIR%\include\Inventor\fields\SoSFULong.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFUShort.h %COINDIR%\include\Inventor\fields\SoSFUShort.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec2b.h %COINDIR%\include\Inventor\fields\SoSFVec2b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec2s.h %COINDIR%\include\Inventor\fields\SoSFVec2s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec2i32.h %COINDIR%\include\Inventor\fields\SoSFVec2i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec2f.h %COINDIR%\include\Inventor\fields\SoSFVec2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec2d.h %COINDIR%\include\Inventor\fields\SoSFVec2d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec3b.h %COINDIR%\include\Inventor\fields\SoSFVec3b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec3s.h %COINDIR%\include\Inventor\fields\SoSFVec3s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec3i32.h %COINDIR%\include\Inventor\fields\SoSFVec3i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec3f.h %COINDIR%\include\Inventor\fields\SoSFVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec3d.h %COINDIR%\include\Inventor\fields\SoSFVec3d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4b.h %COINDIR%\include\Inventor\fields\SoSFVec4b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4ub.h %COINDIR%\include\Inventor\fields\SoSFVec4ub.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4s.h %COINDIR%\include\Inventor\fields\SoSFVec4s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4us.h %COINDIR%\include\Inventor\fields\SoSFVec4us.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4i32.h %COINDIR%\include\Inventor\fields\SoSFVec4i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4ui32.h %COINDIR%\include\Inventor\fields\SoSFVec4ui32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4f.h %COINDIR%\include\Inventor\fields\SoSFVec4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSFVec4d.h %COINDIR%\include\Inventor\fields\SoSFVec4d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\fields\SoSField.h %COINDIR%\include\Inventor\fields\SoSField.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SbList.h %COINDIR%\include\Inventor\lists\SbList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SbPList.h %COINDIR%\include\Inventor\lists\SbPList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SbIntList.h %COINDIR%\include\Inventor\lists\SbIntList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SbVec3fList.h %COINDIR%\include\Inventor\lists\SbVec3fList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SbStringList.h %COINDIR%\include\Inventor\lists\SbStringList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoActionMethodList.h %COINDIR%\include\Inventor\lists\SoActionMethodList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoAuditorList.h %COINDIR%\include\Inventor\lists\SoAuditorList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoBaseList.h %COINDIR%\include\Inventor\lists\SoBaseList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoCallbackList.h %COINDIR%\include\Inventor\lists\SoCallbackList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoDetailList.h %COINDIR%\include\Inventor\lists\SoDetailList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoEnabledElementsList.h %COINDIR%\include\Inventor\lists\SoEnabledElementsList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoEngineList.h %COINDIR%\include\Inventor\lists\SoEngineList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoEngineOutputList.h %COINDIR%\include\Inventor\lists\SoEngineOutputList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoFieldList.h %COINDIR%\include\Inventor\lists\SoFieldList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoNodeList.h %COINDIR%\include\Inventor\lists\SoNodeList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoPathList.h %COINDIR%\include\Inventor\lists\SoPathList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoPickedPointList.h %COINDIR%\include\Inventor\lists\SoPickedPointList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lists\SoTypeList.h %COINDIR%\include\Inventor\lists\SoTypeList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\lock\SoLockMgr.h %COINDIR%\include\Inventor\lock\SoLockMgr.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoClipPlaneManip.h %COINDIR%\include\Inventor\manips\SoClipPlaneManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoDirectionalLightManip.h %COINDIR%\include\Inventor\manips\SoDirectionalLightManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoPointLightManip.h %COINDIR%\include\Inventor\manips\SoPointLightManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoSpotLightManip.h %COINDIR%\include\Inventor\manips\SoSpotLightManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoTransformManip.h %COINDIR%\include\Inventor\manips\SoTransformManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoCenterballManip.h %COINDIR%\include\Inventor\manips\SoCenterballManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoHandleBoxManip.h %COINDIR%\include\Inventor\manips\SoHandleBoxManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoJackManip.h %COINDIR%\include\Inventor\manips\SoJackManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoTabBoxManip.h %COINDIR%\include\Inventor\manips\SoTabBoxManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoTrackballManip.h %COINDIR%\include\Inventor\manips\SoTrackballManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoTransformBoxManip.h %COINDIR%\include\Inventor\manips\SoTransformBoxManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\manips\SoTransformerManip.h %COINDIR%\include\Inventor\manips\SoTransformerManip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\CoinResources.h %COINDIR%\include\Inventor\misc\CoinResources.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoAuditorList.h %COINDIR%\include\Inventor\misc\SoAuditorList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoBase.h %COINDIR%\include\Inventor\misc\SoBase.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoBasic.h %COINDIR%\include\Inventor\misc\SoBasic.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoByteStream.h %COINDIR%\include\Inventor\misc\SoByteStream.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoCallbackList.h %COINDIR%\include\Inventor\misc\SoCallbackList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoChildList.h %COINDIR%\include\Inventor\misc\SoChildList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoContextHandler.h %COINDIR%\include\Inventor\misc\SoContextHandler.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoGLImage.h %COINDIR%\include\Inventor\misc\SoGLImage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoGLCubeMapImage.h %COINDIR%\include\Inventor\misc\SoGLCubeMapImage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoGLBigImage.h %COINDIR%\include\Inventor\misc\SoGLBigImage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoNormalGenerator.h %COINDIR%\include\Inventor\misc\SoNormalGenerator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoNotification.h %COINDIR%\include\Inventor\misc\SoNotification.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoNotRec.h %COINDIR%\include\Inventor\misc\SoNotRec.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoProto.h %COINDIR%\include\Inventor\misc\SoProto.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoProtoInstance.h %COINDIR%\include\Inventor\misc\SoProtoInstance.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoTranReceiver.h %COINDIR%\include\Inventor\misc\SoTranReceiver.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoState.h %COINDIR%\include\Inventor\misc\SoState.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoTranscribe.h %COINDIR%\include\Inventor\misc\SoTranscribe.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoTranSender.h %COINDIR%\include\Inventor\misc\SoTranSender.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoLightPath.h %COINDIR%\include\Inventor\misc\SoLightPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoTempPath.h %COINDIR%\include\Inventor\misc\SoTempPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoGlyph.h %COINDIR%\include\Inventor\misc\SoGlyph.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoAudioDevice.h %COINDIR%\include\Inventor\misc\SoAudioDevice.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoScriptEngine.h %COINDIR%\include\Inventor\misc\SoScriptEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoJavaScriptEngine.h %COINDIR%\include\Inventor\misc\SoJavaScriptEngine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\misc\SoGLDriverDatabase.h %COINDIR%\include\Inventor\misc\SoGLDriverDatabase.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLNavigation.h %COINDIR%\include\Inventor\navigation\SoScXMLNavigation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLNavigationTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLNavigationTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLMiscTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLMiscTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLPanTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLPanTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLRotateTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLRotateTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLSeekTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLSeekTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLSpinTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLSpinTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLZoomTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLZoomTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLDollyTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLDollyTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLFlightControlTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLFlightControlTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\navigation\SoScXMLMotionTarget.h %COINDIR%\include\Inventor\navigation\SoScXMLMotionTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoSubKit.h %COINDIR%\include\Inventor\nodekits\SoSubKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoNodeKit.h %COINDIR%\include\Inventor\nodekits\SoNodeKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoNodeKitListPart.h %COINDIR%\include\Inventor\nodekits\SoNodeKitListPart.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoNodekitCatalog.h %COINDIR%\include\Inventor\nodekits\SoNodekitCatalog.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoBaseKit.h %COINDIR%\include\Inventor\nodekits\SoBaseKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoAppearanceKit.h %COINDIR%\include\Inventor\nodekits\SoAppearanceKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoCameraKit.h %COINDIR%\include\Inventor\nodekits\SoCameraKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoInteractionKit.h %COINDIR%\include\Inventor\nodekits\SoInteractionKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoLightKit.h %COINDIR%\include\Inventor\nodekits\SoLightKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoSceneKit.h %COINDIR%\include\Inventor\nodekits\SoSceneKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoSeparatorKit.h %COINDIR%\include\Inventor\nodekits\SoSeparatorKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoShapeKit.h %COINDIR%\include\Inventor\nodekits\SoShapeKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodekits\SoWrapperKit.h %COINDIR%\include\Inventor\nodekits\SoWrapperKit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoAlphaTest.h %COINDIR%\include\Inventor\nodes\SoAlphaTest.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoAnnotation.h %COINDIR%\include\Inventor\nodes\SoAnnotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoAntiSquish.h %COINDIR%\include\Inventor\nodes\SoAntiSquish.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoArray.h %COINDIR%\include\Inventor\nodes\SoArray.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoAsciiText.h %COINDIR%\include\Inventor\nodes\SoAsciiText.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoBaseColor.h %COINDIR%\include\Inventor\nodes\SoBaseColor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoBlinker.h %COINDIR%\include\Inventor\nodes\SoBlinker.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoBumpMap.h %COINDIR%\include\Inventor\nodes\SoBumpMap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoBumpMapCoordinate.h %COINDIR%\include\Inventor\nodes\SoBumpMapCoordinate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoBumpMapTransform.h %COINDIR%\include\Inventor\nodes\SoBumpMapTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCacheHint.h %COINDIR%\include\Inventor\nodes\SoCacheHint.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCallback.h %COINDIR%\include\Inventor\nodes\SoCallback.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCamera.h %COINDIR%\include\Inventor\nodes\SoCamera.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoClipPlane.h %COINDIR%\include\Inventor\nodes\SoClipPlane.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoColorIndex.h %COINDIR%\include\Inventor\nodes\SoColorIndex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoComplexity.h %COINDIR%\include\Inventor\nodes\SoComplexity.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCone.h %COINDIR%\include\Inventor\nodes\SoCone.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCoordinate3.h %COINDIR%\include\Inventor\nodes\SoCoordinate3.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCoordinate4.h %COINDIR%\include\Inventor\nodes\SoCoordinate4.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCube.h %COINDIR%\include\Inventor\nodes\SoCube.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoCylinder.h %COINDIR%\include\Inventor\nodes\SoCylinder.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoDepthBuffer.h %COINDIR%\include\Inventor\nodes\SoDepthBuffer.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoDirectionalLight.h %COINDIR%\include\Inventor\nodes\SoDirectionalLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoDrawStyle.h %COINDIR%\include\Inventor\nodes\SoDrawStyle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoEnvironment.h %COINDIR%\include\Inventor\nodes\SoEnvironment.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoEventCallback.h %COINDIR%\include\Inventor\nodes\SoEventCallback.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoExtSelection.h %COINDIR%\include\Inventor\nodes\SoExtSelection.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoFaceSet.h %COINDIR%\include\Inventor\nodes\SoFaceSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoFile.h %COINDIR%\include\Inventor\nodes\SoFile.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoFont.h %COINDIR%\include\Inventor\nodes\SoFont.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoFontStyle.h %COINDIR%\include\Inventor\nodes\SoFontStyle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoFrustumCamera.h %COINDIR%\include\Inventor\nodes\SoFrustumCamera.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoGeoOrigin.h %COINDIR%\include\Inventor\nodes\SoGeoOrigin.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoGeoLocation.h %COINDIR%\include\Inventor\nodes\SoGeoLocation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoGeoSeparator.h %COINDIR%\include\Inventor\nodes\SoGeoSeparator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoGeoCoordinate.h %COINDIR%\include\Inventor\nodes\SoGeoCoordinate.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoGroup.h %COINDIR%\include\Inventor\nodes\SoGroup.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoGeometryShader.h %COINDIR%\include\Inventor\nodes\SoGeometryShader.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoImage.h %COINDIR%\include\Inventor\nodes\SoImage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedFaceSet.h %COINDIR%\include\Inventor\nodes\SoIndexedFaceSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedLineSet.h %COINDIR%\include\Inventor\nodes\SoIndexedLineSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedMarkerSet.h %COINDIR%\include\Inventor\nodes\SoIndexedMarkerSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedNurbsCurve.h %COINDIR%\include\Inventor\nodes\SoIndexedNurbsCurve.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedNurbsSurface.h %COINDIR%\include\Inventor\nodes\SoIndexedNurbsSurface.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedPointSet.h %COINDIR%\include\Inventor\nodes\SoIndexedPointSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedShape.h %COINDIR%\include\Inventor\nodes\SoIndexedShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoIndexedTriangleStripSet.h %COINDIR%\include\Inventor\nodes\SoIndexedTriangleStripSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoInfo.h %COINDIR%\include\Inventor\nodes\SoInfo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLOD.h %COINDIR%\include\Inventor\nodes\SoLOD.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLabel.h %COINDIR%\include\Inventor\nodes\SoLabel.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLevelOfDetail.h %COINDIR%\include\Inventor\nodes\SoLevelOfDetail.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLight.h %COINDIR%\include\Inventor\nodes\SoLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLightModel.h %COINDIR%\include\Inventor\nodes\SoLightModel.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLineSet.h %COINDIR%\include\Inventor\nodes\SoLineSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLinearProfile.h %COINDIR%\include\Inventor\nodes\SoLinearProfile.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoListener.h %COINDIR%\include\Inventor\nodes\SoListener.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoLocateHighlight.h %COINDIR%\include\Inventor\nodes\SoLocateHighlight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoMarkerSet.h %COINDIR%\include\Inventor\nodes\SoMarkerSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoMaterial.h %COINDIR%\include\Inventor\nodes\SoMaterial.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoMaterialBinding.h %COINDIR%\include\Inventor\nodes\SoMaterialBinding.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoMatrixTransform.h %COINDIR%\include\Inventor\nodes\SoMatrixTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoMultipleCopy.h %COINDIR%\include\Inventor\nodes\SoMultipleCopy.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNode.h %COINDIR%\include\Inventor\nodes\SoNode.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNodes.h %COINDIR%\include\Inventor\nodes\SoNodes.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNonIndexedShape.h %COINDIR%\include\Inventor\nodes\SoNonIndexedShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNormal.h %COINDIR%\include\Inventor\nodes\SoNormal.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNormalBinding.h %COINDIR%\include\Inventor\nodes\SoNormalBinding.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNurbsCurve.h %COINDIR%\include\Inventor\nodes\SoNurbsCurve.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNurbsProfile.h %COINDIR%\include\Inventor\nodes\SoNurbsProfile.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoNurbsSurface.h %COINDIR%\include\Inventor\nodes\SoNurbsSurface.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoOrthographicCamera.h %COINDIR%\include\Inventor\nodes\SoOrthographicCamera.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPackedColor.h %COINDIR%\include\Inventor\nodes\SoPackedColor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPathSwitch.h %COINDIR%\include\Inventor\nodes\SoPathSwitch.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPendulum.h %COINDIR%\include\Inventor\nodes\SoPendulum.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPerspectiveCamera.h %COINDIR%\include\Inventor\nodes\SoPerspectiveCamera.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPickStyle.h %COINDIR%\include\Inventor\nodes\SoPickStyle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPointLight.h %COINDIR%\include\Inventor\nodes\SoPointLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPointSet.h %COINDIR%\include\Inventor\nodes\SoPointSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoPolygonOffset.h %COINDIR%\include\Inventor\nodes\SoPolygonOffset.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoProfile.h %COINDIR%\include\Inventor\nodes\SoProfile.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoProfileCoordinate2.h %COINDIR%\include\Inventor\nodes\SoProfileCoordinate2.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoProfileCoordinate3.h %COINDIR%\include\Inventor\nodes\SoProfileCoordinate3.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoQuadMesh.h %COINDIR%\include\Inventor\nodes\SoQuadMesh.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoReversePerspectiveCamera.h %COINDIR%\include\Inventor\nodes\SoReversePerspectiveCamera.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoResetTransform.h %COINDIR%\include\Inventor\nodes\SoResetTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoRotation.h %COINDIR%\include\Inventor\nodes\SoRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoRotationXYZ.h %COINDIR%\include\Inventor\nodes\SoRotationXYZ.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoRotor.h %COINDIR%\include\Inventor\nodes\SoRotor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoScale.h %COINDIR%\include\Inventor\nodes\SoScale.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSceneTexture2.h %COINDIR%\include\Inventor\nodes\SoSceneTexture2.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSceneTextureCubeMap.h %COINDIR%\include\Inventor\nodes\SoSceneTextureCubeMap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSelection.h %COINDIR%\include\Inventor\nodes\SoSelection.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSeparator.h %COINDIR%\include\Inventor\nodes\SoSeparator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoShape.h %COINDIR%\include\Inventor\nodes\SoShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoShapeHints.h %COINDIR%\include\Inventor\nodes\SoShapeHints.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoShuttle.h %COINDIR%\include\Inventor\nodes\SoShuttle.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSphere.h %COINDIR%\include\Inventor\nodes\SoSphere.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSpotLight.h %COINDIR%\include\Inventor\nodes\SoSpotLight.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSubNode.h %COINDIR%\include\Inventor\nodes\SoSubNode.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSurroundScale.h %COINDIR%\include\Inventor\nodes\SoSurroundScale.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoSwitch.h %COINDIR%\include\Inventor\nodes\SoSwitch.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoText2.h %COINDIR%\include\Inventor\nodes\SoText2.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoText3.h %COINDIR%\include\Inventor\nodes\SoText3.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTexture.h %COINDIR%\include\Inventor\nodes\SoTexture.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTexture2.h %COINDIR%\include\Inventor\nodes\SoTexture2.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTexture2Transform.h %COINDIR%\include\Inventor\nodes\SoTexture2Transform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTexture3.h %COINDIR%\include\Inventor\nodes\SoTexture3.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTexture3Transform.h %COINDIR%\include\Inventor\nodes\SoTexture3Transform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCombine.h %COINDIR%\include\Inventor\nodes\SoTextureCombine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinate2.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinate2.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinate3.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinate3.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateBinding.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateBinding.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateCube.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateCube.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateCylinder.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateCylinder.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateSphere.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateSphere.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateDefault.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateDefault.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateEnvironment.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateEnvironment.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateFunction.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateFunction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinatePlane.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinatePlane.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateNormalMap.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateNormalMap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateReflectionMap.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateReflectionMap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCoordinateObject.h %COINDIR%\include\Inventor\nodes\SoTextureCoordinateObject.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureCubeMap.h %COINDIR%\include\Inventor\nodes\SoTextureCubeMap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureMatrixTransform.h %COINDIR%\include\Inventor\nodes\SoTextureMatrixTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureScalePolicy.h %COINDIR%\include\Inventor\nodes\SoTextureScalePolicy.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTextureUnit.h %COINDIR%\include\Inventor\nodes\SoTextureUnit.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTransform.h %COINDIR%\include\Inventor\nodes\SoTransform.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTransformSeparator.h %COINDIR%\include\Inventor\nodes\SoTransformSeparator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTransformation.h %COINDIR%\include\Inventor\nodes\SoTransformation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTranslation.h %COINDIR%\include\Inventor\nodes\SoTranslation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTransparencyType.h %COINDIR%\include\Inventor\nodes\SoTransparencyType.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoTriangleStripSet.h %COINDIR%\include\Inventor\nodes\SoTriangleStripSet.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoUnits.h %COINDIR%\include\Inventor\nodes\SoUnits.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoVertexProperty.h %COINDIR%\include\Inventor\nodes\SoVertexProperty.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoVertexAttribute.h %COINDIR%\include\Inventor\nodes\SoVertexAttribute.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoVertexAttributeBinding.h %COINDIR%\include\Inventor\nodes\SoVertexAttributeBinding.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoVertexShape.h %COINDIR%\include\Inventor\nodes\SoVertexShape.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoWWWAnchor.h %COINDIR%\include\Inventor\nodes\SoWWWAnchor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoWWWInline.h %COINDIR%\include\Inventor\nodes\SoWWWInline.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoFragmentShader.h %COINDIR%\include\Inventor\nodes\SoFragmentShader.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoShaderObject.h %COINDIR%\include\Inventor\nodes\SoShaderObject.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoShaderParameter.h %COINDIR%\include\Inventor\nodes\SoShaderParameter.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoShaderProgram.h %COINDIR%\include\Inventor\nodes\SoShaderProgram.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\nodes\SoVertexShader.h %COINDIR%\include\Inventor\nodes\SoVertexShader.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbProjectors.h %COINDIR%\include\Inventor\projectors\SbProjectors.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbCylinderPlaneProjector.h %COINDIR%\include\Inventor\projectors\SbCylinderPlaneProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbCylinderProjector.h %COINDIR%\include\Inventor\projectors\SbCylinderProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbCylinderSectionProjector.h %COINDIR%\include\Inventor\projectors\SbCylinderSectionProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbCylinderSheetProjector.h %COINDIR%\include\Inventor\projectors\SbCylinderSheetProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbLineProjector.h %COINDIR%\include\Inventor\projectors\SbLineProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbPlaneProjector.h %COINDIR%\include\Inventor\projectors\SbPlaneProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbProjector.h %COINDIR%\include\Inventor\projectors\SbProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbSpherePlaneProjector.h %COINDIR%\include\Inventor\projectors\SbSpherePlaneProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbSphereProjector.h %COINDIR%\include\Inventor\projectors\SbSphereProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbSphereSectionProjector.h %COINDIR%\include\Inventor\projectors\SbSphereSectionProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\projectors\SbSphereSheetProjector.h %COINDIR%\include\Inventor\projectors\SbSphereSheetProjector.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoSensors.h %COINDIR%\include\Inventor\sensors\SoSensors.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoAlarmSensor.h %COINDIR%\include\Inventor\sensors\SoAlarmSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoDataSensor.h %COINDIR%\include\Inventor\sensors\SoDataSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoDelayQueueSensor.h %COINDIR%\include\Inventor\sensors\SoDelayQueueSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoFieldSensor.h %COINDIR%\include\Inventor\sensors\SoFieldSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoIdleSensor.h %COINDIR%\include\Inventor\sensors\SoIdleSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoNodeSensor.h %COINDIR%\include\Inventor\sensors\SoNodeSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoOneShotSensor.h %COINDIR%\include\Inventor\sensors\SoOneShotSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoPathSensor.h %COINDIR%\include\Inventor\sensors\SoPathSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoSensor.h %COINDIR%\include\Inventor\sensors\SoSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoSensorManager.h %COINDIR%\include\Inventor\sensors\SoSensorManager.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoTimerQueueSensor.h %COINDIR%\include\Inventor\sensors\SoTimerQueueSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\sensors\SoTimerSensor.h %COINDIR%\include\Inventor\sensors\SoTimerSensor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\system\gl.h %COINDIR%\include\Inventor\system\gl.h >nul:
copy /Y ..\%msvc%\include\Inventor\system\gl-headers.h %COINDIR%\include\Inventor\system\gl-headers.h >nul:
copy /Y ..\%msvc%\include\Inventor\system\inttypes.h %COINDIR%\include\Inventor\system\inttypes.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbThread.h %COINDIR%\include\Inventor\threads\SbThread.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbMutex.h %COINDIR%\include\Inventor\threads\SbMutex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbThreadMutex.h %COINDIR%\include\Inventor\threads\SbThreadMutex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbRWMutex.h %COINDIR%\include\Inventor\threads\SbRWMutex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbCondVar.h %COINDIR%\include\Inventor\threads\SbCondVar.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbStorage.h %COINDIR%\include\Inventor\threads\SbStorage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbTypedStorage.h %COINDIR%\include\Inventor\threads\SbTypedStorage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbFifo.h %COINDIR%\include\Inventor\threads\SbFifo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbBarrier.h %COINDIR%\include\Inventor\threads\SbBarrier.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\threads\SbThreadAutoLock.h %COINDIR%\include\Inventor\threads\SbThreadAutoLock.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\tools\SbPimplPtr.h %COINDIR%\include\Inventor\tools\SbPimplPtr.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\tools\SbPimplPtr.hpp %COINDIR%\include\Inventor\tools\SbPimplPtr.hpp >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\tools\SbLazyPimplPtr.h %COINDIR%\include\Inventor\tools\SbLazyPimplPtr.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\tools\SbLazyPimplPtr.hpp %COINDIR%\include\Inventor\tools\SbLazyPimplPtr.hpp >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXML.h %COINDIR%\include\Inventor\scxml\ScXML.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLSubObject.h %COINDIR%\include\Inventor\scxml\ScXMLSubObject.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLObject.h %COINDIR%\include\Inventor\scxml\ScXMLObject.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLEvent.h %COINDIR%\include\Inventor\scxml\ScXMLEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLEventTarget.h %COINDIR%\include\Inventor\scxml\ScXMLEventTarget.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLStateMachine.h %COINDIR%\include\Inventor\scxml\ScXMLStateMachine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLDocument.h %COINDIR%\include\Inventor\scxml\ScXMLDocument.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLElt.h %COINDIR%\include\Inventor\scxml\ScXMLElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLAbstractStateElt.h %COINDIR%\include\Inventor\scxml\ScXMLAbstractStateElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLExecutableElt.h %COINDIR%\include\Inventor\scxml\ScXMLExecutableElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLAnchorElt.h %COINDIR%\include\Inventor\scxml\ScXMLAnchorElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLAssignElt.h %COINDIR%\include\Inventor\scxml\ScXMLAssignElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLContentElt.h %COINDIR%\include\Inventor\scxml\ScXMLContentElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLDataElt.h %COINDIR%\include\Inventor\scxml\ScXMLDataElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLDataModelElt.h %COINDIR%\include\Inventor\scxml\ScXMLDataModelElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLElseElt.h %COINDIR%\include\Inventor\scxml\ScXMLElseElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLElseIfElt.h %COINDIR%\include\Inventor\scxml\ScXMLElseIfElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLEventElt.h %COINDIR%\include\Inventor\scxml\ScXMLEventElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLFinalElt.h %COINDIR%\include\Inventor\scxml\ScXMLFinalElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLFinalizeElt.h %COINDIR%\include\Inventor\scxml\ScXMLFinalizeElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLHistoryElt.h %COINDIR%\include\Inventor\scxml\ScXMLHistoryElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLIfElt.h %COINDIR%\include\Inventor\scxml\ScXMLIfElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLInitialElt.h %COINDIR%\include\Inventor\scxml\ScXMLInitialElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLInvokeElt.h %COINDIR%\include\Inventor\scxml\ScXMLInvokeElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLLogElt.h %COINDIR%\include\Inventor\scxml\ScXMLLogElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLOnEntryElt.h %COINDIR%\include\Inventor\scxml\ScXMLOnEntryElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLOnExitElt.h %COINDIR%\include\Inventor\scxml\ScXMLOnExitElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLParallelElt.h %COINDIR%\include\Inventor\scxml\ScXMLParallelElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLParamElt.h %COINDIR%\include\Inventor\scxml\ScXMLParamElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLScriptElt.h %COINDIR%\include\Inventor\scxml\ScXMLScriptElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLScxmlElt.h %COINDIR%\include\Inventor\scxml\ScXMLScxmlElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLSendElt.h %COINDIR%\include\Inventor\scxml\ScXMLSendElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLStateElt.h %COINDIR%\include\Inventor\scxml\ScXMLStateElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLTransitionElt.h %COINDIR%\include\Inventor\scxml\ScXMLTransitionElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLValidateElt.h %COINDIR%\include\Inventor\scxml\ScXMLValidateElt.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLEvaluator.h %COINDIR%\include\Inventor\scxml\ScXMLEvaluator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLMinimumEvaluator.h %COINDIR%\include\Inventor\scxml\ScXMLMinimumEvaluator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLXPathEvaluator.h %COINDIR%\include\Inventor\scxml\ScXMLXPathEvaluator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLECMAScriptEvaluator.h %COINDIR%\include\Inventor\scxml\ScXMLECMAScriptEvaluator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\ScXMLCoinEvaluator.h %COINDIR%\include\Inventor\scxml\ScXMLCoinEvaluator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\SoScXMLEvent.h %COINDIR%\include\Inventor\scxml\SoScXMLEvent.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\scxml\SoScXMLStateMachine.h %COINDIR%\include\Inventor\scxml\SoScXMLStateMachine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\Sb.h %COINDIR%\include\Inventor\Sb.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBSPTree.h %COINDIR%\include\Inventor\SbBSPTree.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBasic.h %COINDIR%\include\Inventor\SbBasic.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox.h %COINDIR%\include\Inventor\SbBox.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox2s.h %COINDIR%\include\Inventor\SbBox2s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox2i32.h %COINDIR%\include\Inventor\SbBox2i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox2f.h %COINDIR%\include\Inventor\SbBox2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox2d.h %COINDIR%\include\Inventor\SbBox2d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox3d.h %COINDIR%\include\Inventor\SbBox3d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox3f.h %COINDIR%\include\Inventor\SbBox3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox3i32.h %COINDIR%\include\Inventor\SbBox3i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbBox3s.h %COINDIR%\include\Inventor\SbBox3s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbByteBuffer.h %COINDIR%\include\Inventor\SbByteBuffer.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbByteBuffer.h %COINDIR%\include\Inventor\SbByteBuffer.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbClip.h %COINDIR%\include\Inventor\SbClip.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbColor.h %COINDIR%\include\Inventor\SbColor.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbColor4f.h %COINDIR%\include\Inventor\SbColor4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbColorRGBA.h %COINDIR%\include\Inventor\SbColorRGBA.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbCylinder.h %COINDIR%\include\Inventor\SbCylinder.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDPLine.h %COINDIR%\include\Inventor\SbDPLine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDPLinear.h %COINDIR%\include\Inventor\SbDPLinear.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDPMatrix.h %COINDIR%\include\Inventor\SbDPMatrix.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDPPlane.h %COINDIR%\include\Inventor\SbDPPlane.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDPRotation.h %COINDIR%\include\Inventor\SbDPRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDPViewVolume.h %COINDIR%\include\Inventor\SbDPViewVolume.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbDict.h %COINDIR%\include\Inventor\SbDict.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbHeap.h %COINDIR%\include\Inventor\SbHeap.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbImage.h %COINDIR%\include\Inventor\SbImage.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbLine.h %COINDIR%\include\Inventor\SbLine.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbLinear.h %COINDIR%\include\Inventor\SbLinear.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbMatrix.h %COINDIR%\include\Inventor\SbMatrix.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbName.h %COINDIR%\include\Inventor\SbName.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbOctTree.h %COINDIR%\include\Inventor\SbOctTree.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbPList.h %COINDIR%\include\Inventor\SbPList.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbPlane.h %COINDIR%\include\Inventor\SbPlane.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbRotation.h %COINDIR%\include\Inventor\SbRotation.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbSphere.h %COINDIR%\include\Inventor\SbSphere.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbString.h %COINDIR%\include\Inventor\SbString.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbTesselator.h %COINDIR%\include\Inventor\SbTesselator.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbTime.h %COINDIR%\include\Inventor\SbTime.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbTypeInfo.h %COINDIR%\include\Inventor\SbTypeInfo.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec.h %COINDIR%\include\Inventor\SbVec.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2b.h %COINDIR%\include\Inventor\SbVec2b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2ub.h %COINDIR%\include\Inventor\SbVec2ub.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2s.h %COINDIR%\include\Inventor\SbVec2s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2us.h %COINDIR%\include\Inventor\SbVec2us.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2i32.h %COINDIR%\include\Inventor\SbVec2i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2ui32.h %COINDIR%\include\Inventor\SbVec2ui32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2f.h %COINDIR%\include\Inventor\SbVec2f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec2d.h %COINDIR%\include\Inventor\SbVec2d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3b.h %COINDIR%\include\Inventor\SbVec3b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3ub.h %COINDIR%\include\Inventor\SbVec3ub.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3s.h %COINDIR%\include\Inventor\SbVec3s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3us.h %COINDIR%\include\Inventor\SbVec3us.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3i32.h %COINDIR%\include\Inventor\SbVec3i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3ui32.h %COINDIR%\include\Inventor\SbVec3ui32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3f.h %COINDIR%\include\Inventor\SbVec3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec3d.h %COINDIR%\include\Inventor\SbVec3d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4b.h %COINDIR%\include\Inventor\SbVec4b.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4ub.h %COINDIR%\include\Inventor\SbVec4ub.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4s.h %COINDIR%\include\Inventor\SbVec4s.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4us.h %COINDIR%\include\Inventor\SbVec4us.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4i32.h %COINDIR%\include\Inventor\SbVec4i32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4ui32.h %COINDIR%\include\Inventor\SbVec4ui32.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4f.h %COINDIR%\include\Inventor\SbVec4f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbVec4d.h %COINDIR%\include\Inventor\SbVec4d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbViewVolume.h %COINDIR%\include\Inventor\SbViewVolume.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbViewportRegion.h %COINDIR%\include\Inventor\SbViewportRegion.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbXfBox3f.h %COINDIR%\include\Inventor\SbXfBox3f.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SbXfBox3d.h %COINDIR%\include\Inventor\SbXfBox3d.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\So.h %COINDIR%\include\Inventor\So.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoDB.h %COINDIR%\include\Inventor\SoDB.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoFullPath.h %COINDIR%\include\Inventor\SoFullPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoInput.h %COINDIR%\include\Inventor\SoInput.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoInteraction.h %COINDIR%\include\Inventor\SoInteraction.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoLists.h %COINDIR%\include\Inventor\SoLists.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoNodeKitPath.h %COINDIR%\include\Inventor\SoNodeKitPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoOffscreenRenderer.h %COINDIR%\include\Inventor\SoOffscreenRenderer.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoOutput.h %COINDIR%\include\Inventor\SoOutput.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoPath.h %COINDIR%\include\Inventor\SoPath.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoPickedPoint.h %COINDIR%\include\Inventor\SoPickedPoint.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoPrimitiveVertex.h %COINDIR%\include\Inventor\SoPrimitiveVertex.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoSceneManager.h %COINDIR%\include\Inventor\SoSceneManager.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoRenderManager.h %COINDIR%\include\Inventor\SoRenderManager.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoEventManager.h %COINDIR%\include\Inventor\SoEventManager.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\SoType.h %COINDIR%\include\Inventor\SoType.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\non_winsys.h %COINDIR%\include\Inventor\non_winsys.h >nul:
copy /Y ..\%msvc%\..\..\include\Inventor\oivwin32.h %COINDIR%\include\Inventor\oivwin32.h >nul:
copy /Y ..\%msvc%\..\..\include\SoWinEnterScope.h %COINDIR%\include\SoWinEnterScope.h >nul:
copy /Y ..\%msvc%\..\..\include\SoWinLeaveScope.h %COINDIR%\include\SoWinLeaveScope.h >nul:
copy /Y ..\%msvc%\..\..\include\SoDebug.h %COINDIR%\include\SoDebug.h >nul:
